import { select } from 'd3';

export const main = (container) => {
  const width = container.clientWidth;
  const height = container.clientHeight;

  const svg = select(container)
    .selectAll('svg')
    .data([null])
    .join('svg')
    .attr('width', width)
    .attr('height', height)
    .style('background', 'lightblue'); // A light blue background to represent the sky

  // Owl features
  const owlFeatures = [
    // Body of the owl
    { x: width / 2, y: height / 2 + 50, r: 100, fill: 'brown' },
    // Head of the owl
    { x: width / 2, y: height / 2 - 30, r: 50, fill: 'brown' },
    // Eyes
    { x: width / 2 - 20, y: height / 2 - 50, r: 10, fill: 'yellow' },
    { x: width / 2 + 20, y: height / 2 - 50, r: 10, fill: 'yellow' },
    // Ears
    { x: width / 2 - 30, y: height / 2 - 70, r: 15, fill: 'brown' },
    { x: width / 2 + 30, y: height / 2 - 70, r: 15, fill: 'brown' },
    // Nose (beak)
    { x1: width / 2, y1: height / 2 - 35, x2: width / 2 + 10, y2: height / 2 - 25, stroke: 'orange' },
    // Mouth
    { x1: width / 2 - 10, y1: height / 2 - 30, x2: width / 2 + 10, y2: height / 2 - 30, stroke: 'brown' },
    // Legs
    { x1: width / 2 - 20, y1: height / 2 + 50, x2: width / 2 - 40, y2: height / 2 + 90, stroke: 'brown' },
    { x1: width / 2 + 20, y1: height / 2 + 50, x2: width / 2 + 40, y2: height / 2 + 90, stroke: 'brown' },
    // Tail
    { x1: width / 2 + 50, y1: height / 2 + 50, x2: width / 2 + 100, y2: height / 2 + 70, stroke: 'brown' },
    // Wings
    { x1: width / 2 - 30, y1: height / 2 - 30, x2: width / 2 - 50, y2: height / 2 - 40, stroke: 'brown' },
    { x1: width / 2 + 30, y1: height / 2 - 30, x2: width / 2 + 50, y2: height / 2 - 40, stroke: 'brown' },
    { x1: width / 2 - 30, y1: height / 2 - 10, x2: width / 2 - 50, y2: height / 2, stroke: 'brown' },
    { x1: width / 2 + 30, y1: height / 2 - 10, x2: width / 2 + 50, y2: height / 2, stroke: 'brown' },
  ];

  // Draw the owl's body, head, eyes, ears, beak, mouth, legs, tail, and wings
  svg.selectAll('circle')
    .data(owlFeatures.filter(d => d.hasOwnProperty('r')))
    .join('circle')
    .attr('cx', d => d.x)
    .attr('cy', d => d.y)
    .attr('r', d => d.r)
    .attr('fill', d => d.fill);

  // Draw the lines (beak, mouth, legs, tail, and wings)
  svg.selectAll('line')
    .data(owlFeatures.filter(d => d.hasOwnProperty('x2')))
    .join('line')
    .attr('x1', d => d.x1)
    .attr('y1', d => d.y1)
    .attr('x2', d => d.x2)
    .attr('y2', d => d.y2)
    .attr('stroke', d => d.stroke);
};
